==> google-cloud-cpp-2.13.0.tar.gz: google-cloud-cpp-2.13.0/google/cloud/networksecurity/README.md <==
# Network Security API C++ Client Library

This directory contains an idiomatic C++ client library for the
[Network Security API][cloud-service-docs], a cloud first service that helps you
secure egress web traffic (HTTP/S).

While this library is **GA**, please note that the Google Cloud C++ client
libraries do **not** follow [Semantic Versioning](https://semver.org/).

## Quickstart

The [quickstart/](quickstart/README.md) directory contains a minimal environment
to get started using this client library in a larger project. The following
"Hello World" program is used in this quickstart, and should give you a taste of
this library.

<!-- inject-quickstart-start -->

```cc
#include "google/cloud/networksecurity/v1/network_security_client.h"
#include "google/cloud/project.h"
#include <iostream>

int main(int argc, char* argv[]) try {
  if (argc != 2) {
    std::cerr << "Usage: " << argv[0] << " project-id\n";
    return 1;
  }

  namespace networksecurity = ::google::cloud::networksecurity_v1;
  auto client = networksecurity::NetworkSecurityClient(
      networksecurity::MakeNetworkSecurityConnection());

  auto const parent = std::string{"projects/"} + argv[1] + "/locations/-";
  for (auto r : client.ListAuthorizationPolicies(parent)) {
    if (!r) throw std::move(r).status();
    std::cout << r->DebugString() << "\n";
  }

  return 0;
} catch (google::cloud::Status const& status) {
  std::cerr << "google::cloud::Status thrown: " << status << "\n";
  return 1;
}
```

<!-- inject-quickstart-end -->

## More Information

- Official documentation about the [Network Security API][cloud-service-docs] service
- [Reference doxygen documentation][doxygen-link] for each release of this
  client library
- Detailed header comments in our [public `.h`][source-link] files

[cloud-service-docs]: https://cloud.google.com/secure-web-proxy
[doxygen-link]: https://cloud.google.com/cpp/docs/reference/networksecurity/latest/
[source-link]: https://github.com/googleapis/google-cloud-cpp/tree/main/google/cloud/networksecurity

==> google-cloud-cpp-2.15.1.tar.gz: google-cloud-cpp-2.15.1/google/cloud/networksecurity/README.md <==
# Network Security API C++ Client Library

This directory contains an idiomatic C++ client library for the
[Network Security API][cloud-service-docs], a cloud first service that helps you
secure egress web traffic (HTTP/S).

While this library is **GA**, please note that the Google Cloud C++ client
libraries do **not** follow [Semantic Versioning](https://semver.org/).

## Quickstart

The [quickstart/](quickstart/README.md) directory contains a minimal environment
to get started using this client library in a larger project. The following
"Hello World" program is used in this quickstart, and should give you a taste of
this library.

<!-- inject-quickstart-start -->

```cc
#include "google/cloud/networksecurity/v1/network_security_client.h"
#include "google/cloud/project.h"
#include <iostream>

int main(int argc, char* argv[]) try {
  if (argc != 2) {
    std::cerr << "Usage: " << argv[0] << " project-id\n";
    return 1;
  }

  namespace networksecurity = ::google::cloud::networksecurity_v1;
  auto client = networksecurity::NetworkSecurityClient(
      networksecurity::MakeNetworkSecurityConnection());

  auto const parent = std::string{"projects/"} + argv[1] + "/locations/-";
  for (auto r : client.ListAuthorizationPolicies(parent)) {
    if (!r) throw std::move(r).status();
    std::cout << r->DebugString() << "\n";
  }

  return 0;
} catch (google::cloud::Status const& status) {
  std::cerr << "google::cloud::Status thrown: " << status << "\n";
  return 1;
}
```

<!-- inject-quickstart-end -->

## More Information

- Official documentation about the [Network Security API][cloud-service-docs]
  service
- [Reference doxygen documentation][doxygen-link] for each release of this
  client library
- Detailed header comments in our [public `.h`][source-link] files

[cloud-service-docs]: https://cloud.google.com/secure-web-proxy
[doxygen-link]: https://cloud.google.com/cpp/docs/reference/networksecurity/latest/
[source-link]: https://github.com/googleapis/google-cloud-cpp/tree/main/google/cloud/networksecurity
